% Demo for the dominant set biclustering algorithm:
% 
% - M. Denitto, M. Bicego, A. Farinelli, M. Pelillo: "Dominant Set Biclustering", 
%   Proc. EMMCVPR, 2017
% - M. Denitto, M. Bicego, A. Farinelli, S. Vascon, M. Pelillo: "Biclustering with Dominant Sets", 
%   Pattern Recognition, 2020
% 
% Notes:
% - The algorithm is suitable when background has low values with respect
% to the biclusters (in principle, background is zero, biclusters are positive (larger than zero)
% 
% - The algorithm returns the largest bicluster. To extract more biclusters,
% as often done in the literature, you can “mask” the obtained bicluster and 
% then search for the next one (e.g. by inserting zeros in the corresponding 
% positions of the matrix.)
% 

clear all;
close all

load('bicluster.mat');

figure, subplot(1,2,1),imagesc(data)
title('Original data');


% setting alpha
opt.alpha = -1;  % -1 means that alpha is automatically estimated. 
% Set a different alpha permits to play with the dimension of the obtained bicluster 
% Suggestions: (see the PR paper)
% the value of α is linked to the dimension of the obtained dominant set: the larger α the larger the bicluster

[rowBic,colBic,opt] = DomSet_biclustering(data,opt);

% displaying results
res = zeros(size(data));
res(rowBic,colBic) = 1;
subplot(1,2,2),imagesc(res)
title('Obtained bicluster');
