function [rowBic,colBic,opt] = DomSet_biclustering(D,opt)
%  [rowBic,colBic,opt] = DomSet_biclustering(D,opt)
%
% This function implements the Dominant set biclustering, as described in:
% - M. Denitto, M. Bicego, A. Farinelli, M. Pelillo: "Dominant Set Biclustering", 
%   Proc. EMMCVPR, 2017
% - M. Denitto, M. Bicego, A. Farinelli, S. Vascon, M. Pelillo: "Biclustering with Dominant Sets", 
%   Pattern Recognition, 2020



% some options
opt.maxit = 10^4;
opt.support = eps;
opt.thr = 10^-5;


% Econding
[r,c] = size(D);

A = zeros(sum(size(D)));
A(1:r,r+1:end) = D;
A(r+1:end,1:r) = D';

if opt.alpha == -1
    ee = eigs(A,1);
    opt.alpha =abs(ee)*0.05;
end
A = A + (ones(r+c) - eye(r+c))*opt.alpha;

% A = A - min(A(:));


%% dominant set part
x = ones(sum(size(D)),1);
x = x/length(x);

xnew = x.*(A*x);
xnew = xnew/sum(xnew);

diff = sqrt(sum((x-xnew).^2));

it = 1;
while diff > opt.thr
    x = xnew;
    xnew = x.*(A*x);
    xnew = xnew/sum(xnew);
    it = it + 1;
    if it == opt.maxit
        break;
    end
    diff = sqrt(sum((x-xnew).^2));
end
rowBic = x(1:r)>opt.support;
colBic = x(r+1:end)>opt.support;
end
